====
pydl
====

Introduction
------------

This is the documentation for pydl.

Components
----------

Most of the functionality of pydl is in sub-packages.

.. toctree::
   :maxdepth: 1

   goddard.rst
   photoop.rst
   pydlspec2d.rst
   pydlutils.rst

Other Notes
-----------

.. toctree::
   :maxdepth: 1

   changes.rst
   todo.rst

API
---

.. automodapi:: pydl
   :no-inheritance-diagram:
